@@ -49,7 +49,7 @@ class CreateWebhookRequest(object):
         return payload
 
     def __repr__(self):
-        json.dumps(self.to_json_api())
+        return json.dumps(self.to_json_api())
 
 
 class PatchWebhookRequest(object):
